@@ -1,8 +1,9 @@
 import copy
 
-from skeletal_animation.core.animate import *
+from skeletal_animation.core.animate import Animation, Curve, JointAnimation
 from skeletal_animation.utils.other import are_skeletons_similar
-from skeletal_animation.core.model import *
+from skeletal_animation.core.model import Skeleton
+
 
 class Animator:
     """Controller class to animate a skeleton.
@@ -26,7 +27,13 @@ class Animator:
         Only used when the animator is played by the gui script (frame.py).
     """
 
-    def __init__(self, animation, skeleton, kps=30, interpolation_algo = "linear"):
+    def __init__(
+        self,
+        animation: Animation,
+        skeleton: Skeleton,
+        kps=30,
+        interpolation_algo="linear",
+    ):
         """**Default constructor for the Animator class.**
 
         Parameters:
@@ -34,14 +41,14 @@ class Animator:
         animation : Animation
             Animation to be played.
         skeleton : Skeleton
-            Skeleton to be animated.    
+            Skeleton to be animated.
         kps : int, optional
             Keys per second of the animation, by default 30.
         interpolation_algo : str, optional
             Interpolation algorithm to be used, by default "linear".
             Possible values: "constant" and "linear".
         """
-        self.animation = animation 
+        self.animation = animation
         self.skeleton = skeleton
         self.anim_time = 0
         self.kps = kps
@@ -55,13 +62,12 @@ class Animator:
         Called by the constructor.
 
         Returns:
-        ----------        
+        ----------
         float
             The duration of the animation in seconds.
         """
         return self.animation.max_key_time / self.kps
 
-
     def generate_pose(self):
         """Generates a pose dictionary.
 
@@ -77,7 +83,7 @@ class Animator:
         ----------
         dict (int: Transform)
             Pose dictionary generated.
-            Where the integer key is the id of a joint in the skeleton and 
+            Where the integer key is the id of a joint in the skeleton and
             the transform value is the local animation transform of the joint.
 
         See Also:
@@ -91,15 +97,16 @@ class Animator:
         pose_dict = {}
 
         for joint_animation in self.animation.joint_animations:
-            
-            joint = joint_animation.joint                        
-            
-            local_transform = joint_animation.get_local_transform(time, self.interpolation_algo)
+            joint = joint_animation.joint
 
-            pose_dict[joint.id] = local_transform      
+            local_transform = joint_animation.get_local_transform(
+                time, self.interpolation_algo
+            )
+
+            pose_dict[joint.id] = local_transform
+
+        return pose_dict
 
-        return pose_dict  
-        
     def update(self, time, verbose=False):
         """Updates the animation time.
 
@@ -109,15 +116,14 @@ class Animator:
             Time to be added to the animation time.
             Is affected by the speed of the animation in kps.
         verbose : bool, optional
-            If set to true the effective time added to the animation time 
+            If set to true the effective time added to the animation time
             will be printed. by default False.
         """
         if verbose:
             print("_dt:", time * (self.kps / 30))
         self.anim_time += time * (self.kps / 30)
-    
 
-    def play(self, play_duration = 1., fps=30., verbose=False):
+    def play(self, play_duration=1.0, fps=30.0, verbose=False):
         """Plays the animation for a given duration.
 
         This method is used to simulate the animation without rendering it.
@@ -132,11 +138,10 @@ class Animator:
             The amount of steps to compute per second, by default 30.
         verbose : bool, optional
             If set to true the model transform of each joint will be printed at every step,
-            by default False.    
+            by default False.
         """
         while self.anim_time <= play_duration:
-            self.step(1/fps, verbose)
-
+            self.step(1 / fps, verbose)
 
     def step(self, time, verbose=False):
         """Steps the animation for a given time.
@@ -153,7 +158,7 @@ class Animator:
             Negative values step the animation backwards.
         verbose : bool, optional
             If set to true the current time of the animation and the model transform
-            of each joint will be printed, by default False.        
+            of each joint will be printed, by default False.
         """
         self.update(time, verbose)
         pose_dict = self.generate_pose()
@@ -173,9 +178,9 @@ class Animator:
         ----------
         x : float
             Amount of the translation in the x direction.
-        y : floatthe 
+        y : floatthe
             Amount of the translation in the y direction.
-        z : floatthe 
+        z : floatthe
             Amount of the translation in the z direction.
         """
         animation = self.animation
@@ -191,12 +196,12 @@ class Animator:
         This creates a new animation that is the concatenation of the two.
         The duration of the new animation is the sum of the duration of the two animations.
         Curves are normalized to keep the time values between 0 and 1.
-        
+
         Parameters:
         ----------
         other : Animation
             Animation to be clipped to the current animation.
-        
+
         Returns:
         ----------
         Animator
@@ -207,7 +212,9 @@ class Animator:
         The initial animator objects self and other are not modified.
         """
         if not are_skeletons_similar(self.skeleton, other.skeleton):
-            raise ValueError("Cannot generate blend between the two given animators. Skeletons are not identical.")
+            raise ValueError(
+                "Cannot generate blend between the two given animators. Skeletons are not identical."
+            )
 
         self_animation = copy.deepcopy(self.animation)
         other_animation = copy.deepcopy(other.animation)
@@ -216,61 +223,87 @@ class Animator:
         self_duration_ratio = self_animation.max_key_time / total_duration
 
         new_joint_animations = []
-        
+
         for ja_id in range(len(self.animation.joint_animations)):
             self_joint_animation = self_animation.joint_animations[ja_id]
             other_joint_animation = other_animation.joint_animations[ja_id]
-            new_joint_animation = JointAnimation(self_joint_animation.joint,
-                                                rotation_curve=Curve(),
-                                                translation_curve=Curve(),
-                                                timewarp_curve=Curve())
+            new_joint_animation = JointAnimation(
+                self_joint_animation.joint,
+                rotation_curve=Curve(),
+                translation_curve=Curve(),
+                timewarp_curve=Curve(),
+            )
 
             # translation
             self_translation_curve = self_joint_animation.translation_curve
             other_translation_curve = other_joint_animation.translation_curve
             if self_translation_curve is not None:
-                self_translation_curve.normalize_times(total_duration / self_animation.max_key_time)
+                self_translation_curve.normalize_times(
+                    total_duration / self_animation.max_key_time
+                )
             if other_translation_curve is not None:
-                other_translation_curve.normalize_times(total_duration / other_animation.max_key_time)
+                other_translation_curve.normalize_times(
+                    total_duration / other_animation.max_key_time
+                )
             for key in self_translation_curve.keys:
                 new_joint_animation.translation_curve.set_key_at(key.time, key.value)
             for key in other_translation_curve.keys:
-                new_joint_animation.translation_curve.set_key_at(key.time + self_duration_ratio, key.value)
+                new_joint_animation.translation_curve.set_key_at(
+                    key.time + self_duration_ratio, key.value
+                )
 
             # rotation
             self_rotation_curve = self_joint_animation.rotation_curve
             other_rotation_curve = other_joint_animation.rotation_curve
             if self_rotation_curve is not None:
-                self_rotation_curve.normalize_times(total_duration / self_animation.max_key_time)
+                self_rotation_curve.normalize_times(
+                    total_duration / self_animation.max_key_time
+                )
             if other_rotation_curve is not None:
-                other_rotation_curve.normalize_times(total_duration / other_animation.max_key_time)
+                other_rotation_curve.normalize_times(
+                    total_duration / other_animation.max_key_time
+                )
             for key in self_rotation_curve.keys:
                 new_joint_animation.rotation_curve.set_key_at(key.time, key.value)
             for key in other_rotation_curve.keys:
-                new_joint_animation.rotation_curve.set_key_at(key.time + self_duration_ratio, key.value)
+                new_joint_animation.rotation_curve.set_key_at(
+                    key.time + self_duration_ratio, key.value
+                )
 
             # timewarp
             self_timewarp_curve = self_joint_animation.timewarp_curve
             other_timewarp_curve = other_joint_animation.timewarp_curve
             if self_timewarp_curve is not None:
-                self_timewarp_curve.normalize_times(total_duration / self_animation.max_key_time)
-                self_timewarp_curve.normalize_values(total_duration / self_animation.max_key_time)
+                self_timewarp_curve.normalize_times(
+                    total_duration / self_animation.max_key_time
+                )
+                self_timewarp_curve.normalize_values(
+                    total_duration / self_animation.max_key_time
+                )
             if other_timewarp_curve is not None:
-                other_timewarp_curve.normalize_times(total_duration / other_animation.max_key_time)
-                other_timewarp_curve.normalize_values(total_duration / other_animation.max_key_time)
+                other_timewarp_curve.normalize_times(
+                    total_duration / other_animation.max_key_time
+                )
+                other_timewarp_curve.normalize_values(
+                    total_duration / other_animation.max_key_time
+                )
             for key in self_timewarp_curve.keys:
                 new_joint_animation.timewarp_curve.set_key_at(key.time, key.value)
             for key in other_timewarp_curve.keys:
-                new_joint_animation.timewarp_curve.set_key_at(key.time + self_duration_ratio, key.value + self_duration_ratio)        
+                new_joint_animation.timewarp_curve.set_key_at(
+                    key.time + self_duration_ratio, key.value + self_duration_ratio
+                )
 
-            new_joint_animations.append(new_joint_animation)    
+            new_joint_animations.append(new_joint_animation)
 
         new_animation = Animation(new_joint_animations, total_duration)
         new_skeleton = copy.deepcopy(self.skeleton)
 
-        new_animator = Animator(new_animation, new_skeleton, self.kps, self.interpolation_algo)
+        new_animator = Animator(
+            new_animation, new_skeleton, self.kps, self.interpolation_algo
+        )
 
-        return new_animator       
+        return new_animator
 
     def crop(self, start_time, end_time):
         """Crops the animation to be between the given start and end times.
@@ -285,7 +318,7 @@ class Animator:
             Start time of the cropped animation.
         end_time : float
             End time of the cropped animation.
-        
+
         Returns:
         ----------
         Animator
@@ -295,7 +328,7 @@ class Animator:
         ----------
         ValueError
             If the start time is greater or equal to the end time.
-        
+
         Notes
         -----
         The initial animator object is not modified.
@@ -308,55 +341,83 @@ class Animator:
         new_joint_animations = []
 
         for ja in self_animation.joint_animations:
-            new_joint_animation = JointAnimation(ja.joint,
-                                                rotation_curve=Curve(),
-                                                translation_curve=Curve(),
-                                                timewarp_curve=Curve()) 
-            new_joint_animation.timewarp_curve.remove_key_at(0.0)           
+            new_joint_animation = JointAnimation(
+                ja.joint,
+                rotation_curve=Curve(),
+                translation_curve=Curve(),
+                timewarp_curve=Curve(),
+            )
+            new_joint_animation.timewarp_curve.remove_key_at(0.0)
             new_joint_animation.timewarp_curve.remove_key_at(1.0)
 
             # translation
             self_translation_curve = ja.translation_curve
             if self_translation_curve is not None:
                 for key in self_translation_curve.keys:
-                    start_translation_value = self_translation_curve.get_lerp_value(start_time)
-                    end_translation_value = self_translation_curve.get_lerp_value(end_time)
-                    new_joint_animation.translation_curve.set_key_at(0., start_translation_value)
-                    new_joint_animation.translation_curve.set_key_at(end_time - start_time, end_translation_value)
-                
+                    start_translation_value = self_translation_curve.get_lerp_value(
+                        start_time
+                    )
+                    end_translation_value = self_translation_curve.get_lerp_value(
+                        end_time
+                    )
+                    new_joint_animation.translation_curve.set_key_at(
+                        0.0, start_translation_value
+                    )
+                    new_joint_animation.translation_curve.set_key_at(
+                        end_time - start_time, end_translation_value
+                    )
+
                     if key.time <= end_time and key.time >= start_time:
-                        new_joint_animation.translation_curve.set_key_at(key.time - start_time, key.value)
+                        new_joint_animation.translation_curve.set_key_at(
+                            key.time - start_time, key.value
+                        )
 
             # rotation
             self_rotation_curve = ja.rotation_curve
             if self_rotation_curve is not None:
                 for key in self_rotation_curve.keys:
-                    start_rotation_value = self_rotation_curve.get_lerp_value(start_time)
+                    start_rotation_value = self_rotation_curve.get_lerp_value(
+                        start_time
+                    )
                     end_rotation_value = self_rotation_curve.get_lerp_value(end_time)
-                    new_joint_animation.rotation_curve.set_key_at(0., start_rotation_value)
-                    new_joint_animation.rotation_curve.set_key_at(end_time - start_time, end_rotation_value)
-                
+                    new_joint_animation.rotation_curve.set_key_at(
+                        0.0, start_rotation_value
+                    )
+                    new_joint_animation.rotation_curve.set_key_at(
+                        end_time - start_time, end_rotation_value
+                    )
+
                     if key.time <= end_time and key.time >= start_time:
-                        new_joint_animation.rotation_curve.set_key_at(key.time - start_time, key.value)
+                        new_joint_animation.rotation_curve.set_key_at(
+                            key.time - start_time, key.value
+                        )
 
             # timewarp
             self_timewarp_curve = ja.timewarp_curve
             if self_timewarp_curve is not None:
                 for key in self_timewarp_curve.keys:
-                    start_timewarp_value = self_timewarp_curve.get_lerp_value(start_time)
+                    start_timewarp_value = self_timewarp_curve.get_lerp_value(
+                        start_time
+                    )
                     end_timewarp_value = self_timewarp_curve.get_lerp_value(end_time)
-                    new_joint_animation.timewarp_curve.set_key_at(0., start_timewarp_value)
-                    new_joint_animation.timewarp_curve.set_key_at(end_time - start_time, end_timewarp_value)
-                
+                    new_joint_animation.timewarp_curve.set_key_at(
+                        0.0, start_timewarp_value
+                    )
+                    new_joint_animation.timewarp_curve.set_key_at(
+                        end_time - start_time, end_timewarp_value
+                    )
+
                     if key.time <= end_time and key.time >= start_time:
-                        new_joint_animation.timewarp_curve.set_key_at(key.time - start_time, key.value)
+                        new_joint_animation.timewarp_curve.set_key_at(
+                            key.time - start_time, key.value
+                        )
 
             new_joint_animations.append(new_joint_animation)
 
         for new_ja in new_joint_animations:
             new_timewarp_curve = new_ja.timewarp_curve
             min_timewarp_value = 1.0
-            max_timewarp_value = 0.0     
+            max_timewarp_value = 0.0
 
             for key in new_timewarp_curve.keys:
                 if key.value < min_timewarp_value:
@@ -365,12 +426,14 @@ class Animator:
                     max_timewarp_value = key.value
 
             for key in new_timewarp_curve.keys:
-                key.value -= min_timewarp_value          
+                key.value -= min_timewarp_value
 
             new_ja.translation_curve.normalize_times(end_time - start_time)
             new_ja.rotation_curve.normalize_times(end_time - start_time)
             new_ja.timewarp_curve.normalize_times(end_time - start_time)
-            new_ja.timewarp_curve.normalize_values(max_timewarp_value - min_timewarp_value)
+            new_ja.timewarp_curve.normalize_values(
+                max_timewarp_value - min_timewarp_value
+            )
 
         cropped_duration = (end_time - start_time) * self_animation.max_key_time
 
@@ -386,7 +449,7 @@ class Animator:
         Sets the is_playing flag to False.
         """
         self.is_playing = False
-    
+
     def resume(self):
         """Resumes the animation.
 
